@@ -1,8 +1,7 @@
 package Auto::Mata;
 # ABSTRACT: A simple, reliable finite state machine
-$Auto::Mata::VERSION = '0.02';
+$Auto::Mata::VERSION = '0.03';
 
-use v5.10;
 use strict;
 use warnings;
 use parent 'Exporter';
@@ -91,7 +90,7 @@ sub machine (&) {
 
       push @match, $match, sub {
         my ($from, $input) = @$_;
-        debug('%s -> %s: %s', $from, $to, explain($input));
+        debug('%s -> %s', $from, $to);
 
         do { local $_ = $input; $input = $with->() };
         my $state = [$to, $input];
@@ -132,17 +131,20 @@ sub machine (&) {
 
 sub ready    ($)   { assert_in_the_machine(); $_->{ready} = shift }
 sub terminal ($)   { assert_in_the_machine(); $_->{term}  = shift }
+sub term     ($)   { goto \&terminal }
 sub to       ($;%) { (to   => shift, @_) }
 sub on       ($;%) { (on   => shift, @_) }
 sub with     (&;%) { (with => shift, @_) }
 
 
+my $_transition_args;
+
 sub transition ($%) {
   assert_in_the_machine();
-  state $check = compile($Ident, $Ident, $Type, $Code);
+  $_transition_args ||= compile($Ident, $Ident, $Type, $Code);
 
   my ($arg, %param) = @_;
-  my ($from, $to, $on, $with) = $check->($arg, @param{qw(to on with)});
+  my ($from, $to, $on, $with) = $_transition_args->($arg, @param{qw(to on with)});
 
   croak "transition from state $from to $to is already defined"
     if exists $_->{map}{$from}{$to};
@@ -150,7 +152,7 @@ sub transition ($%) {
   my $state   = declare "STATE_${from}", as Enum[$from];
   my $initial = declare "${from}_TO_${to}_INITIAL", as Tuple[$state, $on];
 
-  $_->{map}{$from} //= {};
+  $_->{map}{$from} ||= {};
 
   $_->{map}{$from}{$to} = {
     initial   => $initial,
@@ -196,7 +198,7 @@ sub explain {
 # guarantees on the return type of transitions.
 #-------------------------------------------------------------------------------
 sub validate {
-  $Automata->assert_valid($_);
+  assert_in_the_machine();
 
   croak 'no ready state defined'
     unless $_->{ready};
@@ -249,7 +251,7 @@ Auto::Mata - A simple, reliable finite state machine
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -294,7 +296,7 @@ version 0.02
   my $prog = $fsm->();
   my $data;
 
-  while ($prog->($data)) {
+  while (my ($state, $output) = $prog->($data)) {
     ;
   }
 
@@ -302,9 +304,30 @@ version 0.02
 
 =head1 DESCRIPTION
 
-Finite state machines (or automata) are a way of modeling the workflow of a
-program as a series of dependent, programmable steps. State machines are useful
-tools for building software that behaves in a highly predictable manner.
+Finite state machines (or automata) are a technique for modeling the workflow
+of a program as a series of dependent, programmable steps. State machines are
+useful tools for building software whose behavior can be predicted with a high
+degree of confidence.
+
+Using a state machine to implement a program helps to ensure determinacy, where
+the program state is known at all times. Designing software this way leads to
+greater accuracy and testability.
+
+=head1 WHAT IS A STATE MACHINE
+
+A program can be described as a set of discrete I<states>. Each state is
+defined by the existence or value of a variable, the presence of a file, etc.
+A state machine replaces the if/else clauses typically used to inspect and
+branch based on run-time conditions.
+
+Rather than performing ad hoc tests using if/else conditions, the program is
+instead described as a set of I<transitions> which move the program from an
+initial state to a final state. The state machine begins in the "ready" state.
+The initial state is described using an identifier and a type constraint (see
+L<Type::Tiny> and L<Types::Standard>).  When input matches the transition's
+initial state, the transition step is executed, after which the new initial
+state is the final state described in the transition. This proceeds until the
+"terminal" state is reached.
 
 =head1 EXPORTED SUBROUTINES
 
@@ -358,6 +381,10 @@ Sets the name given to the "terminal" state. This is the final state held by
 the state machine. Once in this state, the machine will cease to perform any
 more work.
 
+=head2 term
+
+Alias for L</terminal>.
+
 =head2 transition
 
 Defines a transition between two states by matching the symbol identifying the
